==> aws-java-sdk-autoscaling-1.10.68-sources.jar: com/amazonaws/services/autoscaling/model/transform/DescribeAutoScalingNotificationTypesResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.autoscaling.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.autoscaling.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * DescribeAutoScalingNotificationTypesResult StAX Unmarshaller
 */
public class DescribeAutoScalingNotificationTypesResultStaxUnmarshaller
        implements
        Unmarshaller<DescribeAutoScalingNotificationTypesResult, StaxUnmarshallerContext> {

    public DescribeAutoScalingNotificationTypesResult unmarshall(
            StaxUnmarshallerContext context) throws Exception {
        DescribeAutoScalingNotificationTypesResult describeAutoScalingNotificationTypesResult = new DescribeAutoScalingNotificationTypesResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return describeAutoScalingNotificationTypesResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context.testExpression(
                        "AutoScalingNotificationTypes/member", targetDepth)) {
                    describeAutoScalingNotificationTypesResult
                            .getAutoScalingNotificationTypes().add(
                                    StringStaxUnmarshaller.getInstance()
                                            .unmarshall(context));
                    continue;
                }

            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return describeAutoScalingNotificationTypesResult;
                }
            }
        }
    }

    private static DescribeAutoScalingNotificationTypesResultStaxUnmarshaller instance;

    public static DescribeAutoScalingNotificationTypesResultStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new DescribeAutoScalingNotificationTypesResultStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-autoscaling-1.11.21-sources.jar: com/amazonaws/services/autoscaling/model/transform/DescribeAutoScalingNotificationTypesResultStaxUnmarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.autoscaling.model.transform;

import java.util.Map;
import java.util.HashMap;
import java.util.ArrayList;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.autoscaling.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * DescribeAutoScalingNotificationTypesResult StAX Unmarshaller
 */
public class DescribeAutoScalingNotificationTypesResultStaxUnmarshaller
        implements
        Unmarshaller<DescribeAutoScalingNotificationTypesResult, StaxUnmarshallerContext> {

    public DescribeAutoScalingNotificationTypesResult unmarshall(
            StaxUnmarshallerContext context) throws Exception {
        DescribeAutoScalingNotificationTypesResult describeAutoScalingNotificationTypesResult = new DescribeAutoScalingNotificationTypesResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return describeAutoScalingNotificationTypesResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context.testExpression(
                        "AutoScalingNotificationTypes/member", targetDepth)) {
                    describeAutoScalingNotificationTypesResult
                            .withAutoScalingNotificationTypes(StringStaxUnmarshaller
                                    .getInstance().unmarshall(context));
                    continue;
                }

            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return describeAutoScalingNotificationTypesResult;
                }
            }
        }
    }

    private static DescribeAutoScalingNotificationTypesResultStaxUnmarshaller instance;

    public static DescribeAutoScalingNotificationTypesResultStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new DescribeAutoScalingNotificationTypesResultStaxUnmarshaller();
        return instance;
    }
}
